Crate jaq_json

Crate jaq_json 

JSON superset with binary data and non-string object keys.

This crate provides a few macros for formatting / writing; this is done in order to function with both core::fmt::Write and std::io::Write.

Modules

read
JSON support.
write
Functions and macros for writing (parts of) values.

Macros

format_val
Write a value as JSON superset, using a function $f to write sub-values.
style
Apply a style $style to the output of $f.
write_byte
Write a byte.
write_bytes
Write a byte string, including leading and trailing quotes.
write_seq
Write a comma-separated sequence of values $xs with $f.
write_utf8
Write a UTF-8 string as JSON string, including leading and trailing quotes.
write_val
Write a value as JSON, using a custom function for child values.

Structs

Rc
A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference Counted’.

Enums

Num
Integer / decimal number.
Val
JSON superset with binary data and non-string object keys.

Functions

bstr
Display bytes as valid UTF-8 string.
bytes_valrs
Apply a function to bytes and yield the resulting value results.
defs
Definitions of the standard library.
funs
Functions of the standard library.

Type Aliases

Error
Error that can occur during filter execution.
Map
Order-preserving map
ValR
A value or an eRror.
ValX
A value or an eXception.