pub enum Num {
Int(isize),
BigInt(Rc<BigInt>),
Float(f64),
Dec(Rc<String>),
}Expand description
Integer / decimal number.
The speciality of this type is that numbers are distinguished into integers and 64-bit floating-point numbers. This allows using integers to index arrays, while using floating-point numbers to do general math.
Operations on numbers follow a few principles:
- The sum, difference, product, and remainder of two integers is integer.
- Any other operation between two numbers yields a float.
Variants
Int(isize)
Machine-size integer
BigInt(Rc<BigInt>)
Arbitrarily large integer
Float(f64)
Floating-point number
Dec(Rc<String>)
Decimal number
Implementations
Sourceimpl Num
impl Num
Sourcepub fn from_integral<T: Copy + TryInto<isize> + Into<BigInt>>(x: T) -> Self
pub fn from_integral<T: Copy + TryInto<isize> + Into<BigInt>>(x: T) -> Self
Convert from an integral type to a machine-sized or big integer.
Sourcepub fn from_str_radix(i: &str, radix: u32) -> Option<Self>
pub fn from_str_radix(i: &str, radix: u32) -> Option<Self>
Try to parse an integer from a string with given radix.
Sourcepub fn from_dec_str(n: &str) -> Self
pub fn from_dec_str(n: &str) -> Self
Try to parse a decimal string to a Self::Float, else return NaN.