pub enum Val {
Null,
Bool(bool),
Num(Num),
BStr(Box<Bytes>),
TStr(Box<Bytes>),
Arr(Rc<Vec<Val>>),
Obj(Rc<Map<Val, Val>>),
}Expand description
JSON superset with binary data and non-string object keys.
This is the default value type for jaq.
Variants
Null
Null
Bool(bool)
Boolean
Num(Num)
Number
BStr(Box<Bytes>)
Byte string
TStr(Box<Bytes>)
Text string (interpreted as UTF-8)
Note that this does not require the actual bytes to be all valid UTF-8; this just means that the bytes are interpreted as UTF-8. An effort is made to preserve invalid UTF-8 as is, else replace invalid UTF-8 by the Unicode replacement character.
Arr(Rc<Vec<Val>>)
Array
Obj(Rc<Map<Val, Val>>)
Object
Implementations