Functions and macros for writing (parts of) values.
We use macros so that we can create both formatters (core::fmt::Formatter) and writers (std::io::Write) from the same code.
Structs
Functions
- write
- Write a value as JSON.
Functions and macros for writing (parts of) values.
We use macros so that we can create both formatters (core::fmt::Formatter) and writers (std::io::Write) from the same code.