JSON superset with binary data and non-string object keys.
This crate provides a few macros for formatting / writing;
this is done in order to function with both
core::fmt::Write and std::io::Write.
Modules
Macros
- format_
val - Write a value as JSON superset, using a function
$fto write sub-values. - style
- Apply a style
$styleto the output of$f. - write_
byte - Write a byte.
- write_
bytes - Write a byte string, including leading and trailing quotes.
- write_
seq - Write a comma-separated sequence of values
$xswith$f. - write_
utf8 - Write a UTF-8 string as JSON string, including leading and trailing quotes.
- write_
val - Write a value as JSON, using a custom function for child values.
Structs
- Rc
- A single-threaded reference-counting pointer. ‘Rc’ stands for ‘Reference Counted’.
Enums
Functions
- bstr
- Display bytes as valid UTF-8 string.
- bytes_
valrs - Apply a function to bytes and yield the resulting value results.
- defs
- Definitions of the standard library.
- funs
- Functions of the standard library.